@@ -34,6 +34,8 @@ NODE_TYPES = [
     'Occupation',
     'ProblemSolution',
     'Client',
+    'Conversation',
+    'UserGroup',
 ]
 
 def inherited_labels(cls):
